NLSL: sshift.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Functions/Subroutines
sshift.f90 File Reference

Go to the source code of this file.

## Functions/Subroutines
double precision function | sshift (data, spct, ldspct, nsi, npt, nft, ideriv, srange, ctol, noneg, tmpdat, tmpclc, wspec, work, sfac)

## Function/Subroutine Documentation

double precision function sshift | ( | double precision, dimension(npt) | data,
|  | double precision, dimension(ldspct,nsi) | spct,
|  | integer | ldspct,
|  | integer | nsi,
|  | integer | npt,
|  | integer | nft,
|  | integer | ideriv,
|  | double precision | srange,
|  | double precision | ctol,
|  | integer | noneg,
|  | double precision, dimension(2*nft) | tmpdat,
|  | double precision, dimension(2*nft) | tmpclc,
|  | double precision, dimension(ldspct,nsi) | wspec,
|  | double precision, dimension(2*nft) | work,
|  | double precision, dimension(nsi) | sfac
| ) |  |

Definition at line 44 of file sshift.f90.

Here is the call graph for this function: